@@ -7,7 +7,7 @@ use base qw/Template::Benchmark::Engine/;
 
 use Text::MicroTemplate::Extended;
 
-our $VERSION = '1.09_01';
+our $VERSION = '1.03';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -111,7 +111,7 @@ sub benchmark_functions_for_uncached_disk
                     escape_func  => undef,
                     use_cache    => 0,
                     );
-                \$t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                $t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
@@ -144,7 +144,7 @@ sub benchmark_functions_for_memory_cache
                     escape_func  => undef,
                     use_cache    => 1,
                     );
-                \$t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                $t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
